.. spec_plots documentation master file, created by
   sphinx-quickstart on Mon Oct 27 13:03:08 2014.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Documentation for MAST's spectral preview generator: spec_plots
===============================================================

Contents:

.. toctree::
   :numbered:
   :maxdepth: 4

   main_programs
   modules
   diagnostics

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

